###################
phenodata changelog
###################

development
===========

2018-03-12 0.1.0
================
- Implement list-species, list-phases and list-stations for data source DWD
- Improve release process
- Update documentation

2018-03-11 0.0.0
================
- Initial project skeleton
- Add initial documentation
- Add code basics
